@@ -1,15 +1,14 @@
 import unittest
-from unittest.mock import call
+from unittest.mock import call, Mock
 
 from freezegun import freeze_time
 
 from tepet import Timer
-from tests.utils import PatchMixin
 
 
-class TimerTest(unittest.TestCase, PatchMixin):
+class TimerTest(unittest.TestCase):
     def setUp(self):
-        self.printer_mock = self._patch('tepet.timer._printer')
+        self.printer_mock = Mock()
 
     def assertCallsPrinterCorrectly(self):
         calls = [
@@ -20,13 +19,14 @@ class TimerTest(unittest.TestCase, PatchMixin):
 
     def test_timer_works_as_a_contextmanager(self):
         with freeze_time("1970-01-01"):
-            with Timer():
-                pass
+            with Timer(printer=self.printer_mock):
+                pass # noqa
         self.assertCallsPrinterCorrectly()
 
     def test_timer_works_as_a_decorator(self):
-        @Timer()
+        @Timer(printer=self.printer_mock)
         def workload():
+            # noqa
             pass
 
         with freeze_time("1970-01-01"):
